@@ -25,10 +25,10 @@ SOFTWARE.
 '''
 import os, sys
 from pathlib import Path
-from typing import List, Optional, Tuple, Union
+from typing import List, Optional, Set, Tuple, Union
 
-from buildtools import os_utils
-from buildtools.maestro.base_target import SingleBuildTarget
+from .. import os_utils
+from .base_target import SingleBuildTarget
 
 
 class NuitkaTarget(SingleBuildTarget):
@@ -61,8 +61,8 @@ class NuitkaTarget(SingleBuildTarget):
 
         super().__init__(target=str(self.executable_mangled), files=files, dependencies=dependencies)
 
-        self.included_packages: List[str] = []
-        self.enabled_plugins: List[str] = []
+        self.included_packages: Set[str] = set()
+        self.enabled_plugins: Set[str] = set()
 
     def build(self):
         opts: List[str] = [
@@ -73,9 +73,9 @@ class NuitkaTarget(SingleBuildTarget):
         ]
         if os.name != 'nt':
             opts += ['--static-libpython=yes']
-        for pkg in self.included_packages:
+        for pkg in sorted(self.included_packages):
             opts += [f'--include-package={pkg}']
-        for plug in self.enabled_plugins:
+        for plug in sorted(self.enabled_plugins):
             opts += [f'--enable-plugin={plug}']
         opts += [
             f'--output-dir={self.out_dir}',
